@@ -12,7 +12,8 @@ my $module = Wasm::Wasmtime::Module->new(wat => q{
   )
 });
 
-my($foo, $bar) = $module->exports;
+
+my($foo, $bar) = @{ $module->exports };
 
 print $foo->name, "\n";        # foo
 print $foo->type->kind, "\n";  # func
