@@ -4,6 +4,7 @@ use strict;
 use warnings;
 use 5.008004;
 use Wasm::Wasmtime::FFI;
+use Wasm::Wasmtime::Engine;
 use Wasm::Wasmtime::Store;
 use Wasm::Wasmtime::Module::Exports;
 use Wasm::Wasmtime::Module::Imports;
@@ -12,7 +13,7 @@ use Wasm::Wasmtime::ExportType;
 use Carp ();
 
 # ABSTRACT: Wasmtime module class
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 
 $ffi_prefix = 'wasm_module_';
@@ -63,17 +64,34 @@ sub _args
 }
 
 
-$ffi->attach( [ wasmtime_module_new => 'new' ] => ['wasm_store_t', 'wasm_byte_vec_t*', 'opaque*'] => 'wasmtime_error_t' => sub {
-  my $xsub = shift;
-  my $class = shift;
-  my($store, $wasm, $data) = _args(@_);
-  my $ptr;
-  if(my $error = $xsub->($store, $$wasm, \$ptr))
-  {
-    Carp::croak("error creating module: " . $error->message);
-  }
-  bless { ptr => $ptr, store => $store }, $class;
-});
+if(_ver_0_19_0())
+{
+  $ffi->attach( [ wasmtime_module_new => 'new' ] => ['wasm_engine_t', 'wasm_byte_vec_t*', 'opaque*'] => 'wasmtime_error_t' => sub {
+    my $xsub = shift;
+    my $class = shift;
+    my($store, $wasm, $data) = _args(@_);
+    my $ptr;
+    if(my $error = $xsub->($store->engine, $$wasm, \$ptr))
+    {
+      Carp::croak("error creating module: " . $error->message);
+    }
+    bless { ptr => $ptr, store => $store }, $class;
+  });
+}
+else
+{
+  $ffi->attach( [ wasmtime_module_new => 'new' ] => ['wasm_store_t', 'wasm_byte_vec_t*', 'opaque*'] => 'wasmtime_error_t' => sub {
+    my $xsub = shift;
+    my $class = shift;
+    my($store, $wasm, $data) = _args(@_);
+    my $ptr;
+    if(my $error = $xsub->($store, $$wasm, \$ptr))
+    {
+      Carp::croak("error creating module: " . $error->message);
+    }
+    bless { ptr => $ptr, store => $store }, $class;
+  });
+}
 
 $ffi->attach( [ wasmtime_module_validate => 'validate' ] => ['wasm_store_t', 'wasm_byte_vec_t*'] => 'wasmtime_error_t' => sub {
   my $xsub = shift;
@@ -144,7 +162,7 @@ Wasm::Wasmtime::Module - Wasmtime module class
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
